import React, { useState } from 'react';
import { Link } from 'react-router-dom';
import axiosInstance from '../../api/axiosConfig';  

import Sidebar from '../sidebar/Sidebar';

const AddCustomer = () => {
  const [customerData, setCustomerData] = useState({
    name: '',
    age: '',
    gender: '',
    email: '',
    address: '',
    mobileNo: ''
  });

  const handleChange = (e) => {
    const { name, value } = e.target;
    setCustomerData({
      ...customerData,
      [name]: value
    });
  };

  const handleSubmit = async (e) => {
    e.preventDefault();
    try {
      const response = await axiosInstance.post('/api/customers', customerData);
      console.log('Customer data saved:', response.data);
      
    } catch (error) {
      console.error('Error saving customer data:', error);
      
    }
  };

  return (
    <div className="flex flex-row">
      <Sidebar />
      <div className="w-full flex flex-col min-h-screen text-white">
        <div className="min-h-screen text-gray-300 p-6">
          <div className="flex justify-between items-center mb-6">
            <h1 className="text-2xl font-semibold text-orange-500">Add Customer</h1>
            <Link to="/" className="text-orange-500">skip for now</Link>
          </div>
          <div className="grid grid-cols-1 md:grid-cols-3 gap-6">
            {/* Sidebar */}
            <div className="space-y-6">
              <div className="text-center">
                <div className="inline-block relative">
                  <div className="bg-gray-700 w-24 h-24 rounded-full mx-auto"></div>
                  <button className="absolute bottom-0 left-1/2 transform -translate-x-1/2 bg-orange-500 text-white text-xs px-2 py-1 rounded-full">
                    {/* Add Customer Image */}
                  </button>
                </div>
              </div>
              <div>
                <Link to="/">
                  <h2 className="text-lg font-semibold text-black-700">Customer Information</h2>
                </Link>
                <Link to="/measurements">
                  <h2 className="text-lg font-semibold text-black-700">Measurements</h2>
                </Link>
              </div>
            </div>
            {/* Form */}
            <div className="md:col-span-2 space-y-4">
              <form onSubmit={handleSubmit}>
                <div>
                  <label className="block text-sm font-medium text-black-700">Customer Name :</label>
                  <input
                    type="text"
                    name="name"
                    value={customerData.name}
                    onChange={handleChange}
                    className="input-underline"
                    required
                  />
                </div>
                <div>
                  <label className="block text-sm font-medium text-black-700">Age :</label>
                  <input
                    type="number"
                    name="age"
                    value={customerData.age}
                    onChange={handleChange}
                    className="input-underline"
                    required
                  />
                </div>
                <div>
                  <label className="block text-sm font-medium text-black-700">Gender :</label>
                  <input
                    type="text"
                    name="gender"
                    value={customerData.gender}
                    onChange={handleChange}
                    className="input-underline"
                    required
                  />
                </div>
                <div>
                  <label className="block text-sm font-medium text-black-700">Email :</label>
                  <input
                    type="email"
                    name="email"
                    value={customerData.email}
                    onChange={handleChange}
                    className="input-underline"
                    required
                  />
                </div>
                <div>
                  <label className="block text-sm font-medium text-black-700">Address :</label>
                  <input
                    type="text"
                    name="address"
                    value={customerData.address}
                    onChange={handleChange}
                    className="input-underline"
                    required
                  />
                </div>
                <div>
                  <label className="block text-sm font-medium text-black-700">Mobile No :</label>
                  <input
                    type="text"
                    name="mobileNo"
                    value={customerData.mobileNo}
                    onChange={handleChange}
                    className="input-underline"
                    required
                  />
                </div> <br/>
                <div className="text-center">
                  <button type="submit" className="bg-orange-500 text-black px-4 py-2 rounded-md font-semibold text-sm">
                   
                    Save Information
                  </button>
                </div>
              </form>
            </div>
          </div>
        </div>
      </div>
    </div>
  );
};

export default AddCustomer;
